package se.pastille.metrognomewear;

import com.unity3d.player.UnityPlayer;
import android.app.Activity;
import android.content.pm.ActivityInfo;
import android.content.res.Configuration;
import android.graphics.PixelFormat;
import android.os.Bundle;
import android.support.wearable.view.DismissOverlayView;
import android.view.GestureDetector;
import android.view.KeyEvent;
import android.view.MotionEvent;
import android.view.Window;
import android.view.WindowManager;
import android.content.ContextWrapper;


class OverridePlayer extends UnityPlayer  {
	private DismissOverlayView mDismissOverlay;
	private GestureDetector mDetector;


	public OverridePlayer(ContextWrapper contextWrapper)
	{
		super(contextWrapper);
		mDismissOverlay = new DismissOverlayView(contextWrapper);
		addView(mDismissOverlay);

		mDismissOverlay.setIntroText("Longpress to exit");
		mDismissOverlay.showIntroIfNecessary();
		// Configure a gesture detector
		mDetector = new GestureDetector(contextWrapper, new GestureDetector.SimpleOnGestureListener() {
			public void onLongPress(MotionEvent ev) {
				mDismissOverlay.show();
			}
		});
	}

	@Override  public boolean onTouchEvent(MotionEvent motionEvent) {
		return mDetector.onTouchEvent(motionEvent) || this.injectEvent(motionEvent);
	}
}


public class UnityPlayerActivity extends Activity
{

	protected OverridePlayer mUnityPlayer; // don't change the name of this variable; referenced from native code

	// Setup activity layout
	@Override protected void onCreate (Bundle savedInstanceState)
	{
		super.onCreate(savedInstanceState);
		requestWindowFeature(Window.FEATURE_NO_TITLE);

		getWindow().setFormat(PixelFormat.RGBX_8888); // <--- This makes xperia play happy

		mUnityPlayer = new OverridePlayer(this);
		setContentView(mUnityPlayer);
		mUnityPlayer.requestFocus();
		getWindow().addFlags(WindowManager.LayoutParams.FLAG_KEEP_SCREEN_ON);



		ShapeWear.setOnShapeChangeListener(new ShapeWear.OnShapeChangeListener() {
			@Override
			public void shapeDetected(ShapeWear.ScreenShape screenShape) {
				//There is fine.
                if(screenShape ==ShapeWear.ScreenShape.OTHER_ROUND )
                {
                    setRequestedOrientation(ActivityInfo.SCREEN_ORIENTATION_LANDSCAPE);
System.out.println("ActivityInfo.SCREEN_ORIENTATION_LANDSCAPE");


                }
				else if(screenShape ==ShapeWear.ScreenShape.MOTO_ROUND )
				{
					setRequestedOrientation(ActivityInfo.SCREEN_ORIENTATION_LANDSCAPE);
                    System.out.println("ActivityInfo.SCREEN_ORIENTATION_LANDSCAPE");
				}
				else
				{
					setRequestedOrientation(ActivityInfo.SCREEN_ORIENTATION_PORTRAIT);
                    System.out.println("ActivityInfo.SCREEN_ORIENTATION_PORTRAIT");
				}

			}
		});
		ShapeWear.setOnSizeChangeListener(new ShapeWear.OnSizeChangeListener() {
			@Override
			public void sizeDetected(int widthPx, int heightPx) {

			}
		});
		ShapeWear.initShapeWear(this);



	}

	// Quit Unity
	@Override protected void onDestroy ()
	{
		mUnityPlayer.quit();
		super.onDestroy();
	}

	// Pause Unity
	@Override protected void onPause()
	{
		super.onPause();
		mUnityPlayer.pause();
	}

	// Resume Unity
	@Override protected void onResume()
	{
		super.onResume();
		mUnityPlayer.resume();
	}

	// This ensures the layout will be correct.
	@Override public void onConfigurationChanged(Configuration newConfig)
	{
		super.onConfigurationChanged(newConfig);
		mUnityPlayer.configurationChanged(newConfig);
	}

	// Notify Unity of the focus change.
	@Override public void onWindowFocusChanged(boolean hasFocus)
	{
		super.onWindowFocusChanged(hasFocus);
		mUnityPlayer.windowFocusChanged(hasFocus);
	}

	// For some reason the multiple keyevent type is not supported by the ndk.
	// Force event injection by overriding dispatchKeyEvent().
	@Override public boolean dispatchKeyEvent(KeyEvent event)
	{
		if (event.getAction() == KeyEvent.ACTION_MULTIPLE)
			return mUnityPlayer.injectEvent(event);
		return super.dispatchKeyEvent(event);
	}

	// Pass any events not handled by (unfocused) views straight to UnityPlayer
	@Override public boolean onKeyUp(int keyCode, KeyEvent event)     { return mUnityPlayer.injectEvent(event); }
	@Override public boolean onKeyDown(int keyCode, KeyEvent event)   { return mUnityPlayer.injectEvent(event); }
	@Override public boolean onTouchEvent(MotionEvent event)          { return mUnityPlayer.injectEvent(event);}
	/*API12*/ public boolean onGenericMotionEvent(MotionEvent event)  { return mUnityPlayer.injectEvent(event); }
}
